@@ -12,10 +12,12 @@ testthat::test_that("new_observation as list", {
 
 if (requireNamespace("xgboost", quietly=TRUE)) {
   testthat::test_that("check_single_prediction error", {
-    testthat::expect_error(
-      ms <- modelStudio::modelStudio(explainer_xgb,
-                                     new_observation = model_matrix_train[1,],
-                                     show_info = v, B = 3)
+    testthat::expect_warning(
+      testthat::expect_error(
+        ms <- modelStudio::modelStudio(explainer_xgb,
+                                       new_observation = model_matrix_train[1,],
+                                       show_info = v, B = 3)
+      )
     )
   })
 }
@@ -37,8 +39,8 @@ testthat::test_that("removed modelStudioOptions", {
 if (requireNamespace("ranger", quietly=TRUE)) {
   ms <- modelStudio::modelStudio(explain_rf, apartments[1:2,], N = 5, B = 2, show_info = v)
   new_ms <- modelStudio::ms_update_observations(ms, explain_rf, B = 2, show_info = v,
-                                                new_observation = apartments[1,],
-                                                new_observation_y = apartments$m2.price[1])
+                                                new_observation = apartments[3,],
+                                                new_observation_y = apartments$m2.price[3])
 
   testthat::test_that("duplicated ids", {
     testthat::expect_is(new_ms, "modelStudio")
